@@ -8,6 +8,7 @@
 var LibraryBrowser = {
   $Browser__deps: [
     '$callUserCallback',
+    '$getFullscreenElement',
     '$safeSetTimeout',
     '$warnOnce',
 #if FILESYSTEM
@@ -232,9 +233,7 @@ var LibraryBrowser = {
       function fullscreenChange() {
         Browser.isFullscreen = false;
         var canvasContainer = canvas.parentNode;
-        if ((document['fullscreenElement'] || document['mozFullScreenElement'] ||
-             document['msFullscreenElement'] || document['webkitFullscreenElement'] ||
-             document['webkitCurrentFullScreenElement']) === canvasContainer) {
+        if (getFullscreenElement() === canvasContainer) {
           canvas.exitFullscreen = Browser.exitFullscreen;
           if (Browser.lockPointer) canvas.requestPointerLock();
           Browser.isFullscreen = true;
@@ -533,9 +532,7 @@ var LibraryBrowser = {
           h = Math.round(w / Module['forcedAspectRatio']);
         }
       }
-      if (((document['fullscreenElement'] || document['mozFullScreenElement'] ||
-           document['msFullscreenElement'] || document['webkitFullscreenElement'] ||
-           document['webkitCurrentFullScreenElement']) === canvas.parentNode) && (typeof screen != 'undefined')) {
+      if ((getFullscreenElement() === canvas.parentNode) && (typeof screen != 'undefined')) {
          var factor = Math.min(screen.width / w, screen.height / h);
          w = Math.round(w * factor);
          h = Math.round(h * factor);
