@@ -13,6 +13,7 @@ import os
 import shutil
 import textwrap
 import shlex
+import subprocess
 from enum import IntEnum, auto
 from glob import iglob
 from typing import List, Optional
@@ -183,13 +184,15 @@ def create_ninja_file(input_files, filename, libname, cflags, asflags=None, cust
   if asflags is None:
     asflags = []
 
+  join_cmd = shlex.join if os.name == 'posix' else subprocess.list2cmdline
+
   out = f'''\
 # Automatically generated by tools/system_libs.py.  DO NOT EDIT
 
 ninja_required_version = 1.5
 
-ASFLAGS = {shlex.join(asflags)}
-CFLAGS = {shlex.join(cflags)}
+ASFLAGS = {join_cmd(asflags)}
+CFLAGS = {join_cmd(cflags)}
 EMCC = {shared.EMCC}
 EMXX = {shared.EMXX}
 EMAR = {shared.EMAR}
@@ -267,7 +270,7 @@ rule archive
       if customize_build_flags:
         custom_flags = customize_build_flags(flags, src)
         if custom_flags != flags:
-          out += f'  CFLAGS = {shlex.join(custom_flags)}'
+          out += f'  CFLAGS = {join_cmd(custom_flags)}'
       out += '\n'
 
     objects = sorted(objects, key=objectfile_sort_key)
@@ -939,9 +942,10 @@ class libcompiler_rt(MTLibrary, SjLjLibrary):
   # restriction soon: https://reviews.llvm.org/D71738
   force_object_files = True
 
-  cflags = ['-fno-builtin', '-DNDEBUG']
+  cflags = ['-fno-builtin', '-DNDEBUG', '-DCOMPILER_RT_HAS_UNAME=1', '-DCOMPILER_RT_HAS_ATOMICS=1']
   src_dir = 'system/lib/compiler-rt/lib/builtins'
-  includes = ['system/lib/libc']
+  profile_src_dir = 'system/lib/compiler-rt/lib/profile'
+  includes = ['system/lib/libc', 'system/lib/compiler-rt/include']
   excludes = [
     # gcc_personality_v0.c depends on libunwind, which don't include by default.
     'gcc_personality_v0.c',
@@ -973,6 +977,8 @@ class libcompiler_rt(MTLibrary, SjLjLibrary):
     'truncxfhf2.c',
   ]
   src_files = glob_in_path(src_dir, '*.c', excludes=excludes)
+  src_files += glob_in_path(profile_src_dir, '*.c')
+  src_files += glob_in_path(profile_src_dir, '*.cpp')
   src_files += files_in_path(
       path='system/lib/compiler-rt',
       filenames=[
@@ -991,6 +997,34 @@ class libnoexit(Library):
   src_files = ['atexit_dummy.c']
 
 
+class llvmlibc(DebugLibrary, AsanInstrumentedLibrary, MTLibrary):
+  name = 'libllvmlibc'
+  never_force = True
+  includes = ['system/lib/llvm-libc']
+  cflags = ['-Os', '-DLIBC_NAMESPACE=__llvm_libc', '-DLLVM_LIBC', '-DLIBC_COPT_PUBLIC_PACKAGING']
+
+  def get_files(self):
+    files = glob_in_path('system/lib/llvm-libc/src/assert', '*.cpp')
+    files += glob_in_path('system/lib/llvm-libc/src/complex', '**/*.cpp')
+    files += glob_in_path('system/lib/llvm-libc/src/string', '**/*.cpp')
+    files += glob_in_path('system/lib/llvm-libc/src/intypes', '*.cpp')
+    files += glob_in_path('system/lib/llvm-libc/src/strings', '**/*.cpp')
+    files += glob_in_path('system/lib/llvm-libc/src/errno', '**/*.cpp')
+    files += glob_in_path('system/lib/llvm-libc/src/math', '*.cpp')
+    files += glob_in_path('system/lib/llvm-libc/src/wchar', '*.cpp')
+    files += glob_in_path('system/lib/llvm-libc/src/setjmp', '*.cpp')
+    files += glob_in_path('system/lib/llvm-libc/src/setjmp', '**/*.cpp')
+    files += glob_in_path('system/lib/llvm-libc/src/stdlib', '*.cpp', excludes=['at_quick_exit.cpp',
+                                                                                'quick_exit.cpp',
+                                                                                'atexit.cpp',
+                                                                                'exit.cpp',
+                                                                                '_Exit.cpp',
+                                                                                'getenv.cpp'])
+    files += glob_in_path('system/lib/llvm-libc/src/math/generic', '**/*.cpp', excludes=['atan2l.cpp', 'exp_utils.cpp'])
+    files += glob_in_path('system/lib/llvm-libc/src/__support/StringUtil', '**/*.cpp')
+    return files
+
+
 class libc(MuslInternalLibrary,
            DebugLibrary,
            AsanInstrumentedLibrary,
@@ -1264,6 +1298,10 @@ class libc(MuslInternalLibrary,
         path='system/lib/libc/musl/src/linux',
         filenames=['getdents.c', 'gettid.c', 'utimes.c', 'statx.c', 'wait4.c', 'wait3.c'])
 
+    libc_files += files_in_path(
+        path='system/lib/libc/musl/src/malloc',
+        filenames=['reallocarray.c'])
+
     libc_files += files_in_path(
         path='system/lib/libc/musl/src/sched',
         filenames=['sched_yield.c'])
@@ -1642,7 +1680,7 @@ class libcxxabi(ExceptionLibrary, MTLibrary, DebugLibrary):
         filenames=filenames)
 
 
-class libcxx(ExceptionLibrary, MTLibrary):
+class libcxx(ExceptionLibrary, MTLibrary, DebugLibrary):
   name = 'libc++'
 
   cflags = [
@@ -2096,9 +2134,7 @@ class libubsan_minimal_rt(CompilerRTLibrary, MTLibrary):
 
 class libsanitizer_common_rt(CompilerRTLibrary, MTLibrary):
   name = 'libsanitizer_common_rt'
-  # TODO(sbc): We should not need musl-internal headers here.
-  includes = ['system/lib/libc/musl/src/internal',
-              'system/lib/compiler-rt/lib',
+  includes = ['system/lib/compiler-rt/lib',
               'system/lib/libc']
   never_force = True
   cflags = [
@@ -2202,7 +2238,7 @@ class libstandalonewasm(MuslInternalLibrary):
   def get_default_variation(cls, **kwargs):
     return super().get_default_variation(
       is_mem_grow=settings.ALLOW_MEMORY_GROWTH,
-      is_pure=settings.PURE_WASI,
+      is_pure=settings.PURE_WASI or settings.GROWABLE_ARRAYBUFFERS,
       nocatch=settings.DISABLE_EXCEPTION_CATCHING and not settings.WASM_EXCEPTIONS,
       **kwargs,
     )
@@ -2426,7 +2462,6 @@ def get_libs_to_link(options):
 
 
 def calculate(options):
-
   libs_to_link = get_libs_to_link(options)
 
   # When LINKABLE is set the entire link command line is wrapped in --whole-archive by
